<script setup>
import { ref, nextTick } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';

const formTable = ref(null);
const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {}
let formData = ref(initFormData);
const treeData = ref(null);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;
    post(isSave.value ? '/api/dept/save' : '/api/dept/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
        nextTick(() => {
            formTable.value.resetFields()
        })
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const UserQueryList = ref(null);
UserQuery();
function UserQuery() {
    postForm('/api/user/query', {}).then(resp => {
        let result = resp.data;
        UserQueryList.value = result.data;
    })
}


defineExpose({
    open,
    formData,
    initFormData,
    treeData,
    isSave,
})

</script>

<script>
export default {
    name: '部门管理-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" ref="formTable" name="formTable" :label-col="{ span: 8 }" :wrapper-col="{ span: 16 }"
                style="display: flex;justify-content: space-between;flex-wrap: wrap;" autocomplete="off"
                @finish="onFinish" @finishFailed="onFinishFailed">
                <a-form-item label="上级部门" name="parentId" style="width: 250px;"
                    :rules="[{ required: true, message: '上级菜单不能为空!' }]">
                    <a-tree-select v-model:value="formData.parentId" show-search style="width: 100%"
                        :dropdown-style="{ maxHeight: '400px', overflow: 'auto' }" :placeholder="formatMessage('page.input', '请输入')"
                        allow-clea tree-data-simple-mode :tree-data="treeData" tree-node-filter-prop="name"
                        :field-names="{
                            children: 'children',
                            label: 'name',
                            value: 'id',
                        }">
                        <template #title="{ value: id, name }">
                            {{ name }}
                        </template>
                    </a-tree-select>
                </a-form-item>
                <a-form-item label="部门名称" name="name" style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.name" />
                </a-form-item>
                <a-form-item label="负责人" name="leader" style="width: 250px;">
                    <a-input v-model:value="formData.leader" />
                </a-form-item>
                <a-form-item label="排序" name="sort" style="width: 250px;">
                    <a-input v-model:value="formData.sort" />
                </a-form-item>
                <a-form-item label="状态" name="status" style="width: 250px;">
                    <a-select v-model:value="formData.status" :options="[
                        { label: '正常', value: 1 },
                        { label: '禁用', value: 0 },
                    ]">
                    </a-select>
                </a-form-item>
                <a-form-item label="备注" name="memo" style="width: 250px;">
                    <a-input v-model:value="formData.memo" />
                </a-form-item>
                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>
